# PyRTC
### An RTC connection manager for Python
----------------------------------------

I'll write some more here later :)

For now, you can read the docs and see
a simple example at https://pyrtc.readthedocs.io/en/latest/